@@ -59,7 +59,7 @@ fn main() {
 }
 ```
 */
-#[macro_export]
+#[macro_export(local_inner_macros)]
 macro_rules! py_exception {
     ($module: ident, $name: ident, $base: ty) => {
         pub struct $name($crate::PyObject);
@@ -105,7 +105,7 @@ macro_rules! py_exception {
                     if type_object.is_null() {
                         type_object = $crate::PyErr::new_type(
                             py,
-                            concat!(stringify!($module), ".", stringify!($name)),
+                            _cpython__err__concat!(_cpython__err__stringify!($module), ".", _cpython__err__stringify!($name)),
                             Some($crate::PythonObject::into_object(py.get_type::<$base>())),
                             None).as_type_ptr();
                     }
@@ -144,9 +144,9 @@ impl PyErr {
     /// Creates a new PyErr of type `T`.
     ///
     /// `value` can be:
-    /// * `NoArgs`: the exception instance will be created using python `T()`
-    /// * a tuple: the exception instance will be created using python `T(*tuple)`
-    /// * any other value: the exception instance will be created using python `T(value)`
+    ///  * `NoArgs`: the exception instance will be created using python `T()`
+    ///  * a tuple: the exception instance will be created using python `T(*tuple)`
+    ///  * any other value: the exception instance will be created using python `T(value)`
     ///
     /// Panics if `T` is not a python class derived from `BaseException`.
     ///
@@ -426,7 +426,7 @@ pub unsafe fn result_cast_from_owned_ptr<T>(py : Python, p : *mut ffi::PyObject)
     if p.is_null() {
         Err(PyErr::fetch(py))
     } else {
-        Ok(try!(PyObject::from_owned_ptr(py, p).cast_into(py)))
+        Ok(PyObject::from_owned_ptr(py, p).cast_into(py)?)
     }
 }
 
@@ -450,6 +450,25 @@ pub fn error_on_minusone(py : Python, result : libc::c_int) -> PyResult<()> {
     }
 }
 
+
+// 2018 macros support
+//
+#[doc(hidden)]
+#[macro_export]
+macro_rules! _cpython__err__concat {
+    ($($inner:tt)*) => {
+        concat! { $($inner)* }
+    }
+}
+
+#[doc(hidden)]
+#[macro_export]
+macro_rules! _cpython__err__stringify {
+    ($($inner:tt)*) => {
+        stringify! { $($inner)* }
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use {Python, PyErr};
