@@ -56,7 +56,7 @@
 //! default-features = false
 //! features = ["python27-sys"]
 //! ```
-//! 
+//!
 //! # Error Handling
 //! The vast majority of operations in this library will return `PyResult<...>`.
 //! This is an alias for the type `Result<..., PyErr>`.
@@ -171,14 +171,14 @@ macro_rules! py_impl_from_py_object_for_python_object {
             #[inline]
             fn extract(py: $crate::Python, obj: &'source $crate::PyObject) -> $crate::PyResult<$T> {
                 use $crate::PyClone;
-                Ok(try!(obj.clone_ref(py).cast_into::<$T>(py)))
+                Ok(obj.clone_ref(py).cast_into::<$T>(py)?)
             }
         }
 
         impl <'source> $crate::FromPyObject<'source> for &'source $T {
             #[inline]
             fn extract(py: $crate::Python, obj: &'source $crate::PyObject) -> $crate::PyResult<&'source $T> {
-                Ok(try!(obj.cast_as::<$T>(py)))
+                Ok(obj.cast_as::<$T>(py)?)
             }
         }
     }
