@@ -41,12 +41,14 @@ impl ToPyObject for bool {
     }
 }
 
-/// Converts a Python `bool` to a rust `bool`.
-///
-/// Fails with `TypeError` if the input is not a Python `bool`.
-extract!(obj to bool; py => {
-    Ok(try!(obj.cast_as::<PyBool>(py)).is_true())
-});
+extract!(obj to bool;
+    /// Converts a Python `bool` to a rust `bool`.
+    ///
+    /// Fails with `TypeError` if the input is not a Python `bool`.
+    py => {
+        Ok(obj.cast_as::<PyBool>(py)?.is_true())
+    }
+);
 
 #[cfg(test)]
 mod test {
